@@ -12,18 +12,21 @@ def __constattr__(arg):
     receptor = type(arg.__name__, (object,), __pc);
     return receptor();
 
-@__constattr__
 class info(object):
-    hist_len = 8;
-    pred_len = 16;
-    clip_len = hist_len + pred_len;
-    num_scales = 4;
-    disc_lrate = 5e-5;
-    gen_lrate = 5e-5;
-    train_dim = (64, 64);
-    pred_dim = (415, 350);
-    scale_min = 1.0 / (2.0 ** (num_scales - 1));
-    scale_up = 2.0;
+    """
+        parameters initialized to `None` should be added in
+        using util.info_json()
+    """
+    hist_len = None;
+    pred_len = None;
+    clip_len = None;
+    num_scales = None;
+    disc_lrate = None;
+    gen_lrate = None;
+    train_dim = None;
+    pred_dim = None;
+    scale_min = None;
+    scale_up = None;
     path = util.get_dir(os.path.expanduser("~/.dohamaps"));
     clips_path = util.get_dir(os.path.join(path, "clips"));
     save_path = util.get_dir(os.path.join(path, "save"));
